import Vue from 'vue';
import { Args, ArgType, StoryContext } from '@storybook/addons';
import { AnyIcon } from './iconTypes';
/**
 * ArgType options for an icon dropdown.
 *
 * @example
 *     argTypes: {
 *         icon: {
 *             ...makeIconArgType(),
 *             defaultValue: 'wvuiIconAdd'
 *         }
 *     }
 * @return Object that can be spread into an ArgType object
 */
export declare function makeIconArgType(): ArgType;
/**
 * Like makeIconArgType(), but with a '(none)' option.
 *
 * @return Object that can be spread into an ArgType object
 */
export declare function makeOptionalIconArgType(): ArgType;
/**
 * Map an icon name to its icon object.
 *
 * This is typically used to map the value of an icon argtype to an actual icon.
 *
 * @example
 *    computed: {
 *         iconData() {
 *             return lookupIcon( this.icon );
 *         }
 *    },
 *    template: `
 *        <wvui-some-component :icon="iconData" v-bind="$props" />
 *    `
 * @param iconName Name of an icon
 * @return The icon object for that icon name, or an empty string if there is no such icon
 */
export declare function lookupIcon(iconName: string): AnyIcon;
declare const _default: {
    title: string;
    component: import("vue/types/vue").ExtendedVue<Vue, Record<string, string>, {
        onClick(event: Event): void;
    }, {
        rootClasses: Record<string, boolean>;
        lacksTitle: boolean;
        iconPath: string;
    }, {
        icon: AnyIcon;
        iconColor: string;
        iconTitle: any;
        langCode: string;
    }>;
    argTypes: {
        icon: {
            defaultValue: string;
            name?: string | undefined;
            description?: string | undefined;
        };
        iconColor: {
            control: {
                type: string;
                presetColors: {
                    color: string;
                    title: string;
                }[];
            };
        };
        iconTitle: {
            control: string;
        };
        langCode: {
            control: {
                type: string;
                options: string[];
            };
            defaultValue: string;
        };
        dir: {
            options: string[];
            control: {
                type: string;
                labels: {
                    ltr: string;
                    rtl: string;
                };
            };
            defaultValue: string;
            description: string;
        };
    };
    parameters: {
        layout: string;
    };
    includeStories: RegExp;
};
export default _default;
export declare const Configurable: (args: Args, { argTypes }: StoryContext) => Vue.Component;
export declare const AllIcons: {
    (_args: Args, { argTypes }: StoryContext): Vue.Component;
    argTypes: {
        icon: {
            table: {
                disable: boolean;
            };
        };
        langCode: {
            table: {
                disable: boolean;
            };
        };
        dir: {
            table: {
                disable: boolean;
            };
        };
    };
};
